netapp_ontap.models.dcn_service_processor API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.dcn_service_processor`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DcnServiceProcessorSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DcnServiceProcessor object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `autoupdate_enabled: bool GET PATCH`

    Indicates whether the service processor can be automatically updated from ONTAP.

  `dhcp_enabled: bool GET PATCH`

    Set to "true" to use DHCP to configure an IPv4 interface. Do not provide values for address, netmask and gateway when set to "true".

  `firmware_version: str GET`

    The version of firmware installed.

  `ipv4_interface: Ipv4Interface GET POST PATCH`

    Object to set up an interface along with its default router.

  `ipv6_interface: Ipv6Interface GET PATCH`

    Object to setup an interface along with its default router.

  `is_ip_configured: bool GET`

    Indicates whether the service processor network is configured.

  `last_update_state: str GET`

    Provides the "update status" of the last service processor update.

    Valid choices:

    - failed
    - passed
  `link_state: str GET`

    The link_state field of the dcn_service_processor.

    Valid choices:

    - up
    - down
    - disabled
    - unknown
  `mac_address: str GET`

    The mac_address field of the dcn_service_processor.

  `state: str GET`

    The state field of the dcn_service_processor.

    Valid choices:

    - online
    - offline
    - degraded
    - rebooting
    - unknown
    - updating
    - node_offline
    - sp_daemon_offline